@@ -6,6 +6,10 @@
 #
 from __future__ import unicode_literals
 import os
+try:
+    import ssl
+except ImportError:
+    ssl = None
 import sys
 
 from compat import unittest
@@ -29,6 +33,7 @@ PYPI_WEB_HOST = os.environ.get('PYPI_WEB_HOST', 'https://pypi.python.org/simple/
 class LocatorTestCase(unittest.TestCase):
 
     @unittest.skipIf('SKIP_ONLINE' in os.environ, 'Skipping online test')
+    @unittest.skipUnless(ssl, 'SSL required for this test.')
     def test_xmlrpc(self):
         locator = PyPIRPCLocator(PYPI_RPC_HOST)
         try:
@@ -53,6 +58,7 @@ class LocatorTestCase(unittest.TestCase):
         self.assertGreater(len(names), 25000)
 
     @unittest.skipIf('SKIP_ONLINE' in os.environ, 'Skipping online test')
+    @unittest.skipUnless(ssl, 'SSL required for this test.')
     def test_json(self):
         locator = PyPIJSONLocator(PYPI_RPC_HOST)
         result = locator.get_project('sarge')
@@ -62,13 +68,14 @@ class LocatorTestCase(unittest.TestCase):
         dist = result[LATEST_SARGE_VERSION]
         self.assertEqual(dist.name, 'sarge')
         self.assertEqual(dist.version, LATEST_SARGE_VERSION)
-        url = ('https://pypi.python.org/packages/source/s/sarge/'
-               'sarge-%s.tar.gz' % LATEST_SARGE_VERSION)
-        self.assertIn(url, dist.download_urls)
+        path = '/sarge-%s.tar.gz' % LATEST_SARGE_VERSION
+        for url in dist.download_urls:
+            self.assertTrue(url.endswith(path))
         self.assertEqual(dist.digests[url],('md5', LATEST_SARGE_MD5))
         self.assertRaises(NotImplementedError, locator.get_distribution_names)
 
     @unittest.skipIf('SKIP_ONLINE' in os.environ, 'Skipping online test')
+    @unittest.skipUnless(ssl, 'SSL required for this test.')
     def test_scraper(self):
         locator = SimpleScrapingLocator('https://pypi.python.org/simple/')
         for name in ('sarge', 'Sarge'):
@@ -77,9 +84,7 @@ class LocatorTestCase(unittest.TestCase):
             dist = result['0.1']
             self.assertEqual(dist.name, 'sarge')
             self.assertEqual(dist.version, '0.1')
-            self.assertEqual(dist.source_url,
-                             'https://pypi.python.org/packages/source/s/sarge/'
-                             'sarge-0.1.tar.gz')
+            self.assertTrue(dist.source_url.endswith('/sarge-0.1.tar.gz'))
             self.assertEqual(dist.digest,
                              ('md5', '961ddd9bc085fdd8b248c6dd96ceb1c8'))
         return
@@ -88,6 +93,7 @@ class LocatorTestCase(unittest.TestCase):
         self.assertGreater(len(names), 25000)
 
     @unittest.skipIf('SKIP_ONLINE' in os.environ, 'Skipping online test')
+    @unittest.skipUnless(ssl, 'SSL required for this test.')
     def test_unicode_project_name(self):
         # Just checking to see that no exceptions are raised.
         NAME = '\u2603'
@@ -166,6 +172,7 @@ class LocatorTestCase(unittest.TestCase):
             sys.path.pop(0)
 
     @unittest.skipIf('SKIP_ONLINE' in os.environ, 'Skipping online test')
+    @unittest.skipUnless(ssl, 'SSL required for this test.')
     def test_aggregation(self):
         d = os.path.join(HERE, 'fake_archives')
         loc1 = DirectoryLocator(d)
@@ -174,7 +181,7 @@ class LocatorTestCase(unittest.TestCase):
         locator = AggregatingLocator(loc1, loc2)
         exp1 = os.path.join(HERE, 'fake_archives', 'subdir',
                             'subsubdir', 'Flask-0.9.tar.gz')
-        exp2 = 'https://pypi.python.org/packages/source/F/Flask/Flask-0.9.tar.gz'
+        exp2 = '/Flask-0.9.tar.gz'
         result = locator.get_project('flask')
         self.assertEqual(len(result), 3)
         self.assertIn('0.9', result)
@@ -193,7 +200,7 @@ class LocatorTestCase(unittest.TestCase):
         dist = result['0.9']
         self.assertEqual(dist.name, 'Flask')
         self.assertEqual(dist.version, '0.9')
-        self.assertEqual(dist.source_url, exp2)
+        self.assertTrue(dist.source_url.endswith(exp2))
         return
         # The following code is slow because it has
         # to get all the dist names by scraping :-(
@@ -202,6 +209,7 @@ class LocatorTestCase(unittest.TestCase):
         self.assertEqual(locator.get_distribution_names(), n1 | n2)
 
     @unittest.skipIf('SKIP_ONLINE' in os.environ, 'Skipping online test')
+    @unittest.skipUnless(ssl, 'SSL required for this test.')
     def test_dependency_finder(self):
         locator = AggregatingLocator(
             JSONLocator(),
@@ -278,6 +286,7 @@ class LocatorTestCase(unittest.TestCase):
         self.assertTrue(actual[0].startswith('Jinja2 ('))
 
     @unittest.skipIf('SKIP_ONLINE' in os.environ, 'Skipping online test')
+    @unittest.skipUnless(ssl, 'SSL required for this test.')
     def test_get_all_dist_names(self):
         for url in (None, PYPI_RPC_HOST):
             try:
@@ -294,6 +303,7 @@ class LocatorTestCase(unittest.TestCase):
             self.assertEqual(default_locator.prefer_url(url1, url2), url1)
 
     @unittest.skipIf('SKIP_ONLINE' in os.environ, 'Skipping online test')
+    @unittest.skipUnless(ssl, 'SSL required for this test.')
     def test_prereleases(self):
         locator = AggregatingLocator(
             JSONLocator(),
@@ -323,6 +333,7 @@ class LocatorTestCase(unittest.TestCase):
         self.assertFalse(problems)
 
     @unittest.skipIf('SKIP_ONLINE' in os.environ, 'Skipping online test')
+    @unittest.skipUnless(ssl, 'SSL required for this test.')
     def test_dist_reqts(self):
         r = 'config (<=0.3.5)'
         dist = default_locator.locate(r)
@@ -332,6 +343,7 @@ class LocatorTestCase(unittest.TestCase):
         self.assertFalse(dist.matches_requirement('config (0.3.6)'))
 
     @unittest.skipIf('SKIP_ONLINE' in os.environ, 'Skipping online test')
+    @unittest.skipUnless(ssl, 'SSL required for this test.')
     def test_dist_reqts_extras(self):
         r = 'config[doc,test](<=0.3.5)'
         dist = default_locator.locate(r)
@@ -340,6 +352,7 @@ class LocatorTestCase(unittest.TestCase):
         self.assertEqual(dist.extras, ['doc', 'test'])
 
     @unittest.skipIf('SKIP_ONLINE' in os.environ, 'Skipping online test')
+    @unittest.skipUnless(ssl, 'SSL required for this test.')
     def test_all(self):
         d = default_locator.get_project('setuptools')
         self.assertTrue('urls' in d)
@@ -489,6 +502,7 @@ class LocatorTestCase(unittest.TestCase):
         self.assertEqual(actual & expected, expected)
 
     @unittest.skipIf('SKIP_ONLINE' in os.environ, 'Skipping online test')
+    @unittest.skipUnless(ssl, 'SSL required for this test.')
     def test_nonexistent(self):
         # See Issue #58
         d = locate('foobarbazbishboshboo')
