@@ -9,6 +9,10 @@ from itertools import islice
 import os
 import re
 import shutil
+try:
+    import ssl
+except ImportError:
+    ssl = None
 import sys
 import tempfile
 import textwrap
@@ -26,7 +30,8 @@ from distlib.util import (get_export_entry, ExportEntry, resolve,
                           EventMixin, Sequencer, unarchive, Progress,
                           iglob, RICH_GLOB, parse_requirement, get_extras,
                           Configurator, read_exports, write_exports,
-                          FileOperator, is_string_sequence, get_package_data)
+                          FileOperator, is_string_sequence, get_package_data,
+                          convert_path)
 
 
 HERE = os.path.dirname(os.path.abspath(__file__))
@@ -152,6 +157,15 @@ class UtilTestCase(unittest.TestCase):
                                         'pytest_dist'),
                          ('pytest_xdist', '0.1_myfork', None))
 
+    def test_convert_path(self):
+        CP = convert_path
+        if os.sep == '/':
+            d = os.path.dirname(__file__)
+            self.assertEqual(CP(d), d)
+        else:
+            self.assertEqual(CP(''), '')
+            self.assertRaises(ValueError, CP, '/foo')
+            self.assertRaises(ValueError, CP, 'foo/')
 
     def test_events(self):
         collected = []
@@ -375,6 +389,14 @@ class UtilTestCase(unittest.TestCase):
                 ('install_data',), ('install_scripts',), ('install_lib',),
                 ('install_headers',), ('build',), ('build_scripts',),
                 ('build_py',), ('build_ext',), ('build_clibs',), ('check',)
+            ],
+            # Next case added for Python 3.6
+            [
+                ('upload_sdist',), ('sdist',), ('upload_bdist',), ('register',),
+                ('install',), ('install_distinfo',), ('install_data',),
+                ('install_scripts',), ('install_lib',), ('install_headers',),
+                ('test',), ('build',), ('build_scripts',), ('build_py',),
+                ('build_ext',), ('build_clibs',), ('check',)
             ]
         )
         self.assertIn(actual, expected)
@@ -464,6 +486,7 @@ class UtilTestCase(unittest.TestCase):
         self.assertRaises(AssertionError, is_string_sequence, [])
 
     @unittest.skipIf('SKIP_ONLINE' in os.environ, 'Skipping online test')
+    @unittest.skipUnless(ssl, 'SSL required for this test.')
     def test_package_data(self):
         data = get_package_data(name='config', version='0.3.6')
         self.assertTrue(data)
